<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//en_GB

$LANG=array();


$LANG['backup'][0]="SQL Dump"; 
$LANG['backup'][1]="XML Dump"; 
$LANG['backup'][11]="Size"; 
$LANG['backup'][13]="View/Download"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Delete this file"; 
$LANG['backup'][18]="Backup the database"; 
$LANG['backup'][19]="Now"; 
$LANG['backup'][21]="The file already exists"; 
$LANG['backup'][22]="Unable to find the byte"; 
$LANG['backup'][23]="Mysql error starting from"; 
$LANG['backup'][24]="Automatic redirection, else click"; 

$LANG['bookmark'][1]="bookmark"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="You have not recorded any bookmarks yet."; 
$LANG['bookmark'][4]="New bookmark"; 
$LANG['bookmark'][5]="Public bookmarks"; 
$LANG['bookmark'][6]="Default view"; 

$LANG['buttons'][0]="Search"; 
$LANG['buttons'][2]="Post"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Install"; 
$LANG['buttons'][5]="Uninstall"; 
$LANG['buttons'][6]="To delete"; 
$LANG['buttons'][7]="Update"; 
$LANG['buttons'][8]="Add"; 
$LANG['buttons'][9]="Connect"; 
$LANG['buttons'][10]="Disconnect"; 
$LANG['buttons'][11]="Next"; 
$LANG['buttons'][12]="Previous"; 
$LANG['buttons'][13]="Back"; 
$LANG['buttons'][14]="Update"; 
$LANG['buttons'][15]="Calendar"; 
$LANG['buttons'][16]="Blank"; 
$LANG['buttons'][17]="Invert the selection"; 
$LANG['buttons'][18]="Check All"; 
$LANG['buttons'][19]="Uncheck All"; 
$LANG['buttons'][20]="Move"; 
$LANG['buttons'][21]="Restore"; 
$LANG['buttons'][22]="Purge"; 
$LANG['buttons'][23]="Show"; 
$LANG['buttons'][24]="Go up"; 
$LANG['buttons'][25]="Go down"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Export"; 
$LANG['buttons'][32]="End"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Cancel"; 
$LANG['buttons'][37]="Import"; 
$LANG['buttons'][38]="Unlock"; 
$LANG['buttons'][39]="Replace"; 
$LANG['buttons'][40]="Show all"; 
$LANG['buttons'][41]="Enable"; 
$LANG['buttons'][42]="Deactivate"; 
$LANG['buttons'][43]="Browse"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Before"; 
$LANG['buttons'][47]="After"; 
$LANG['buttons'][48]="Transfer"; 
$LANG['buttons'][49]="Preserve"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Save"; 
$LANG['buttons'][52]="Load"; 
$LANG['buttons'][53]="Clean"; 
$LANG['buttons'][55]="First"; 
$LANG['buttons'][56]="Last"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="S"; 
$LANG['calendarD'][1]="M"; 
$LANG['calendarD'][2]="T"; 
$LANG['calendarD'][3]="W"; 
$LANG['calendarD'][4]="T"; 
$LANG['calendarD'][5]="F"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Sunday"; 
$LANG['calendarDay'][1]="Monday"; 
$LANG['calendarDay'][2]="Tuesday"; 
$LANG['calendarDay'][3]="Wednesday"; 
$LANG['calendarDay'][4]="Thursday"; 
$LANG['calendarDay'][5]="Friday"; 
$LANG['calendarDay'][6]="Saturday"; 

$LANG['calendarM'][0]="January"; 
$LANG['calendarM'][1]="February"; 
$LANG['calendarM'][2]="March"; 
$LANG['calendarM'][3]="April"; 
$LANG['calendarM'][4]="May"; 
$LANG['calendarM'][5]="June"; 
$LANG['calendarM'][6]="July"; 
$LANG['calendarM'][7]="August"; 
$LANG['calendarM'][8]="September"; 
$LANG['calendarM'][9]="October"; 
$LANG['calendarM'][10]="November"; 
$LANG['calendarM'][11]="December"; 

$LANG['cartridges'][0]="Cartridge"; 
$LANG['cartridges'][7]="No cartridge found"; 
$LANG['cartridges'][9]="No cartridge"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Cartridge Type"; 
$LANG['cartridges'][13]="New"; 
$LANG['cartridges'][14]="Used"; 
$LANG['cartridges'][15]="Worn"; 
$LANG['cartridges'][16]="Cartridge(s)"; 
$LANG['cartridges'][20]="New"; 
$LANG['cartridges'][21]="Used"; 
$LANG['cartridges'][22]="Worn"; 
$LANG['cartridges'][24]="Add Date"; 
$LANG['cartridges'][27]="On"; 
$LANG['cartridges'][29]="End of life"; 
$LANG['cartridges'][32]="Models of compatible printers"; 
$LANG['cartridges'][33]="Used Cartridges"; 
$LANG['cartridges'][34]="No free cartridge"; 
$LANG['cartridges'][35]="Used cartridges"; 
$LANG['cartridges'][37]="Ribbon"; 
$LANG['cartridges'][39]="Printer counter"; 
$LANG['cartridges'][40]="Average Time in stock"; 
$LANG['cartridges'][41]="Average Time in use"; 
$LANG['cartridges'][42]="Average number of printed pages"; 

$LANG['central'][2]="Last"; 
$LANG['central'][4]="No Event"; 
$LANG['central'][5]="Home"; 
$LANG['central'][6]="Logout"; 
$LANG['central'][7]="Help"; 
$LANG['central'][8]="Additions"; 
$LANG['central'][9]="Your tickets in progress"; 
$LANG['central'][10]="New tickets"; 
$LANG['central'][12]="Personal View"; 
$LANG['central'][13]="Global View"; 
$LANG['central'][14]="Group View"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="No"; 
$LANG['choice'][1]="Yes"; 

$LANG['common'][0]="Without name"; 
$LANG['common'][1]="Item"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Manufacturer"; 
$LANG['common'][6]="Template Name"; 
$LANG['common'][7]="Choose a template"; 
$LANG['common'][8]="Manage templates..."; 
$LANG['common'][9]="Add a template..."; 
$LANG['common'][10]="Technician in charge of the hardware"; 
$LANG['common'][11]="Limited view"; 
$LANG['common'][12]="Setup"; 
$LANG['common'][13]="Template"; 
$LANG['common'][14]="Templates"; 
$LANG['common'][15]="Location"; 
$LANG['common'][16]="Name"; 
$LANG['common'][17]="Type"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Serial Number"; 
$LANG['common'][20]="Inventory number"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operation successful"; 
$LANG['common'][24]="No selected element or badly defined operation"; 
$LANG['common'][25]="Comments"; 
$LANG['common'][26]="Last update"; 
$LANG['common'][27]="Date"; 
$LANG['common'][28]="Deleted"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="New Item"; 
$LANG['common'][31]="Blank Template"; 
$LANG['common'][32]="Characteristics"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="User"; 
$LANG['common'][35]="Group"; 
$LANG['common'][36]="Category (class)"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Duplicate the element as many times as there are connections"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Email Alarms"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="First name"; 
$LANG['common'][44]="Default value(s)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Progress"; 
$LANG['common'][48]="Surname"; 
$LANG['common'][49]="None"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Complete Name"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="List"; 
$LANG['common'][54]="Item not found"; 
$LANG['common'][55]="Are you sure you want to delete this element?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Title"; 
$LANG['common'][58]="Maximum value"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Active"; 
$LANG['common'][61]="Unknown error"; 
$LANG['common'][62]="Other"; 
$LANG['common'][63]="Error(s)"; 
$LANG['common'][64]="Manager"; 
$LANG['common'][65]="Interface"; 
$LANG['common'][66]="All"; 
$LANG['common'][67]="Others"; 
$LANG['common'][68]="Landscape"; 
$LANG['common'][69]="Portrait"; 
$LANG['common'][70]="Item successfully added"; 
$LANG['common'][71]="Item successfully updated"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Item successfully restored"; 
$LANG['common'][75]="No right to make this item recursive in this entity"; 
$LANG['common'][76]="Public"; 
$LANG['common'][77]="Private"; 
$LANG['common'][78]="Set public"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="During loading..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Change visibility in the child entities"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="New card"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Free percentage"; 
$LANG['computers'][2]="Free size"; 
$LANG['computers'][3]="Global size"; 
$LANG['computers'][4]="File system"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Add a volume"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Inserted"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="No connected monitor."; 
$LANG['computers'][38]="No connected printer"; 
$LANG['computers'][39]="Printer(s)"; 
$LANG['computers'][40]="Monitor(s)"; 
$LANG['computers'][46]="Devices"; 
$LANG['computers'][47]="No connected device"; 
$LANG['computers'][48]="Location updated. The items connected have been moved in the same location."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="User or group updated. The items connected have been moved in the same values."; 
$LANG['computers'][51]="Update Source"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="No phone connected"; 
$LANG['computers'][55]="Phone(s)"; 
$LANG['computers'][56]="Status updated. The connected items have been updated using this status."; 

$LANG['connect'][0]="Direct Connections"; 
$LANG['connect'][1]="Not connected."; 
$LANG['connect'][15]="Automatic update of the following items"; 
$LANG['connect'][16]="Warning!! The following two items of hardware do not match"; 

$LANG['consumables'][0]="Consumable"; 
$LANG['consumables'][1]="In stock"; 
$LANG['consumables'][2]="Reference"; 
$LANG['consumables'][7]="No consumable found"; 
$LANG['consumables'][9]="No consumable"; 
$LANG['consumables'][12]="Consumable Type"; 
$LANG['consumables'][13]="New"; 
$LANG['consumables'][15]="Used"; 
$LANG['consumables'][16]="Consumable(s)"; 
$LANG['consumables'][20]="New"; 
$LANG['consumables'][22]="Used"; 
$LANG['consumables'][23]="State"; 
$LANG['consumables'][26]="Use date"; 
$LANG['consumables'][32]="Give"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Stock location"; 
$LANG['consumables'][37]="Back to stock"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Add a new component"; 
$LANG['devices'][1]="Hard Drive"; 
$LANG['devices'][2]="Graphics Card"; 
$LANG['devices'][3]="Network Card"; 
$LANG['devices'][4]="Processor"; 
$LANG['devices'][5]="System Board"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Soundcard"; 
$LANG['devices'][19]="Drives"; 
$LANG['devices'][20]="Controllers"; 
$LANG['devices'][21]="Other Components"; 
$LANG['devices'][22]="Cases"; 
$LANG['devices'][23]="Power Supply"; 
$LANG['devices'][24]="by default"; 
$LANG['devices'][25]="Add a component"; 
$LANG['devices'][26]="Deletion of a component"; 

$LANG['device_case'][0]="Size"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Writing ability"; 
$LANG['device_drive'][1]="Speed"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Capacity"; 

$LANG['device_iface'][0]="Flow"; 
$LANG['device_iface'][2]="Mac address"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Power"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frequency"; 
$LANG['device_ram'][2]="Size"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="File"; 
$LANG['document'][3]="Heading"; 
$LANG['document'][4]="MIME Type"; 
$LANG['document'][7]="Document Type"; 
$LANG['document'][9]="Extension"; 
$LANG['document'][10]="Icon"; 
$LANG['document'][11]="Authorized download"; 
$LANG['document'][15]="Download"; 
$LANG['document'][16]="Add a document"; 
$LANG['document'][18]="Document"; 
$LANG['document'][19]="Associated items"; 
$LANG['document'][21]="Associated documents"; 
$LANG['document'][22]="Current File"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Succesful deletion of the file"; 
$LANG['document'][25]="Failed to delete the file"; 
$LANG['document'][26]="The file is valid. Upload is successful."; 
$LANG['document'][27]="Potential upload attack, Or file too large. Moving temporary file failed."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Failed to create the directory"; 
$LANG['document'][30]="Verify that you have the correct permissions"; 
$LANG['document'][31]="Directory for documents does not exist"; 
$LANG['document'][32]="Unauthorized file type"; 
$LANG['document'][33]="Web Link"; 
$LANG['document'][34]="Create the directory"; 
$LANG['document'][35]="Upload directory does not exist"; 
$LANG['document'][36]="Use a FTP installed file"; 
$LANG['document'][37]="No file available"; 
$LANG['document'][38]="File not found"; 
$LANG['document'][39]="Document move succeeded"; 
$LANG['document'][40]="File move failed"; 
$LANG['document'][41]="Document copy succeeded"; 
$LANG['document'][42]="Added by"; 
$LANG['document'][43]="Unknown File"; 
$LANG['document'][44]="Invalid Filename"; 
$LANG['document'][45]="Unauthorized access to this file"; 
$LANG['document'][46]="Failure in sending the file (probably too large)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Entity"; 
$LANG['entity'][2]="Root entity"; 
$LANG['entity'][3]="Associate with an entity"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Automatic user assignment"; 
$LANG['entity'][7]="tree structure"; 
$LANG['entity'][8]="By entity"; 
$LANG['entity'][9]="Child entities"; 
$LANG['entity'][10]="Select the desired entity"; 
$LANG['entity'][11]="to see the entity and its sub-entities"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Service"; 
$LANG['event'][3]="Level"; 
$LANG['event'][4]="Message"; 
$LANG['event'][18]="Field"; 
$LANG['event'][19]="Update"; 
$LANG['event'][20]="No historical"; 

$LANG['financial'][1]="Contract"; 
$LANG['financial'][2]="Lifelong"; 
$LANG['financial'][3]="Financial Information"; 
$LANG['financial'][4]="Number"; 
$LANG['financial'][5]="Cost"; 
$LANG['financial'][6]="Contract Type"; 
$LANG['financial'][8]="Duration"; 
$LANG['financial'][9]="year(s)"; 
$LANG['financial'][10]="Notice"; 
$LANG['financial'][11]="Invoice period"; 
$LANG['financial'][13]="Account number"; 
$LANG['financial'][14]="Date of purchase"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Warranty Information"; 
$LANG['financial'][18]="Order number"; 
$LANG['financial'][19]="Delivery form"; 
$LANG['financial'][20]="Immobilization number"; 
$LANG['financial'][21]="Value"; 
$LANG['financial'][22]="Amortization Type"; 
$LANG['financial'][23]="Amortization duration"; 
$LANG['financial'][24]="Add Contact..."; 
$LANG['financial'][25]="Add Supplier..."; 
$LANG['financial'][26]="Supplier"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Add a Contact"; 
$LANG['financial'][36]="Add a Contract"; 
$LANG['financial'][42]="Commercial"; 
$LANG['financial'][43]="Technician"; 
$LANG['financial'][44]="Address"; 
$LANG['financial'][45]="Website"; 
$LANG['financial'][46]="Associated contacts"; 
$LANG['financial'][47]="Linear"; 
$LANG['financial'][48]="Decreasing"; 
$LANG['financial'][50]="Loan"; 
$LANG['financial'][51]="Renting"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Insurance"; 
$LANG['financial'][54]="Hardware Support"; 
$LANG['financial'][55]="Software Support"; 
$LANG['financial'][56]="Service provided"; 
$LANG['financial'][57]="month"; 
$LANG['financial'][59]="Support hours"; 
$LANG['financial'][60]="on week"; 
$LANG['financial'][61]="on Saturday"; 
$LANG['financial'][62]="Sundays and holidays"; 
$LANG['financial'][65]="Associated suppliers"; 
$LANG['financial'][66]="Associated contracts"; 
$LANG['financial'][68]="Enable the financial information"; 
$LANG['financial'][69]="Contract renewal period"; 
$LANG['financial'][76]="Startup date"; 
$LANG['financial'][77]="Amortization coefficient"; 
$LANG['financial'][78]="Warranty ends value"; 
$LANG['financial'][79]="Third party Type"; 
$LANG['financial'][80]="Warranty expiration date"; 
$LANG['financial'][81]="Account net value"; 
$LANG['financial'][82]="Invoice Number"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="For this type of element, the financial information is only a model for the elements which you should add."; 
$LANG['financial'][85]="Requested item not found"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Budget"; 
$LANG['financial'][88]="Valid to:"; 
$LANG['financial'][89]="TCO (value + tracking cost)"; 
$LANG['financial'][90]="Monthly TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Contracts expired - last 30 days"; 
$LANG['financial'][94]="Contracts expiring in less than 7 days"; 
$LANG['financial'][95]="Contracts expiring in less than 30 days"; 
$LANG['financial'][96]="Contracts where notice begins in less than 7 days"; 
$LANG['financial'][97]="Contracts where notice begins in less than 30 days"; 
$LANG['financial'][98]="Expiration"; 
$LANG['financial'][99]="Expiration date + Notice"; 
$LANG['financial'][100]="Postal Code"; 
$LANG['financial'][101]="City"; 
$LANG['financial'][102]="State"; 
$LANG['financial'][103]="Country"; 
$LANG['financial'][104]="Associated Items"; 
$LANG['financial'][105]="Tacit"; 
$LANG['financial'][106]="Express"; 
$LANG['financial'][107]="Renewal"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="hour(s)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Very High"; 
$LANG['help'][4]="High"; 
$LANG['help'][5]="Medium"; 
$LANG['help'][6]="Low"; 
$LANG['help'][7]="Very Low"; 
$LANG['help'][8]="Inform me about the action(s) taken"; 
$LANG['help'][11]="My E-Mail"; 
$LANG['help'][14]="Submit Message"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Your message has been sent successfully, your request is on file."; 
$LANG['help'][19]="Thank you for using our automatic helpdesk system."; 
$LANG['help'][22]="Search the ID of your computer"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Hardware Type"; 
$LANG['help'][25]="Computer"; 
$LANG['help'][26]="Networking device"; 
$LANG['help'][27]="Printer"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Device"; 
$LANG['help'][30]="General"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Phone"; 
$LANG['help'][40]="No title in your ticket, please retry."; 
$LANG['help'][41]="No category in your ticket, please retry."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Installation or update of GLPI"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Installation"; 
$LANG['install'][4]="Update"; 
$LANG['install'][5]="Checking of the compatibility of your environment with the execution of GLPI"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Results"; 
$LANG['install'][8]="Testing PHP Parser"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP version is at least 5.x - Perfect !"; 
$LANG['install'][12]="Sessions Test"; 
$LANG['install'][13]="Your PHP parser was not compiled with sessions support !"; 
$LANG['install'][14]="Sessions support is available  - Perfect !"; 
$LANG['install'][15]="Make sure that sessions support has been activated in your php.ini"; 
$LANG['install'][16]="Checking write permissions for dump files"; 
$LANG['install'][17]="The file could not be created."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="The file was created but can't be deleted."; 
$LANG['install'][20]="A file and a directory have be created and deleted - Perfect !"; 
$LANG['install'][21]="Checking write permissions for document files"; 
$LANG['install'][22]="A file was created - Perfect !"; 
$LANG['install'][23]="Checking write permissions for setting files"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Continue ?"; 
$LANG['install'][26]="Continue"; 
$LANG['install'][27]="Try again"; 
$LANG['install'][28]="Database connection setup"; 
$LANG['install'][29]="Database connection parameters"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Test of the connection at the database"; 
$LANG['install'][35]="Can't connect to the database"; 
$LANG['install'][36]="The server answered"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Please select a database:"; 
$LANG['install'][39]="Create a new database or use an existing one:"; 
$LANG['install'][40]="Please select the database to update:"; 
$LANG['install'][41]="Impossible to use the database:"; 
$LANG['install'][43]="OK - database was initialized"; 
$LANG['install'][47]="Impossible to write the database setup file"; 
$LANG['install'][48]="Error in creating database !"; 
$LANG['install'][49]="You didn't select a database !"; 
$LANG['install'][50]="Checking write permissions for session files"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Checking write permissions for log files"; 
$LANG['install'][55]="The installation is finished"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="glpi/glpi for the  administrator account"; 
$LANG['install'][59]="tech/tech for the technician account"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Use GLPI"; 
$LANG['install'][65]="magic_quotes_sybase extension test"; 
$LANG['install'][66]="GLPI does not work with the magic_quotes_sybase option ; Please turn it off and retry"; 
$LANG['install'][67]="The magic_quotes_sybase option isn't active on your server - Perfect !"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Can't create the database connection file, please verify file permissions."; 
$LANG['install'][71]="Mysql extension test."; 
$LANG['install'][72]="You must compile your php with the Mysql extension."; 
$LANG['install'][73]="Ok - the function mysql_query() exist - Perfect !"; 
$LANG['install'][74]="Test if Session_use_trans_sid is used"; 
$LANG['install'][75]="You must desactivate the Session_use_trans_id option in your php.ini"; 
$LANG['install'][76]="Ok - the sessions works (no problem with trans_id) - Perfect !"; 
$LANG['install'][77]="Step"; 
$LANG['install'][81]="Beginning of the installation"; 
$LANG['install'][82]="Database created"; 
$LANG['install'][85]="The functionality is found - Perfect!"; 
$LANG['install'][86]="Allocated memory test"; 
$LANG['install'][87]="Allocated memory:"; 
$LANG['install'][88]="A minimum of 64MB is commonly required for GLPI."; 
$LANG['install'][89]="Perfect !"; 
$LANG['install'][90]="Try increasing the memory_limit parameter in the php.ini file."; 
$LANG['install'][91]="Allocated memory > 64M"; 
$LANG['install'][92]="Licence"; 
$LANG['install'][93]="I have read and ACCEPT the terms of the license written above."; 
$LANG['install'][94]="I have read and DO NOT ACCEPT the terms of the license written above"; 
$LANG['install'][95]="Unlimited memory"; 
$LANG['install'][96]="Unlimited memory"; 
$LANG['install'][97]="Check permissions to the directory:"; 
$LANG['install'][99]="Checking write permissions for cache files"; 
$LANG['install'][100]="The directory could not be created."; 
$LANG['install'][101]="The directory was created but could not be removed."; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI can't work correctly without the json_encode and json_decode functions"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="by"; 
$LANG['job'][4]="Requester"; 
$LANG['job'][5]="Assigned to"; 
$LANG['job'][6]="Technician"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Describe the Problem/Action"; 
$LANG['job'][12]="No follow-ups for this ticket."; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Email Follow-ups"; 
$LANG['job'][20]="Total duration"; 
$LANG['job'][21]="Hour(s)"; 
$LANG['job'][22]="Minute(s)"; 
$LANG['job'][29]="Add a new follow-up"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Duration"; 
$LANG['job'][32]="None"; 
$LANG['job'][33]="Empty Description"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planning"; 
$LANG['job'][37]="Summary"; 
$LANG['job'][38]="Ticket"; 
$LANG['job'][39]="Update follow-up"; 
$LANG['job'][40]="Time cost"; 
$LANG['job'][41]="Fixed cost"; 
$LANG['job'][42]="Material cost"; 
$LANG['job'][43]="Total cost"; 
$LANG['job'][44]="Request source"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Just my ones"; 
$LANG['joblist'][2]="Priority"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Assigned"; 
$LANG['joblist'][6]="Description"; 
$LANG['joblist'][7]="New ticket for this item..."; 
$LANG['joblist'][8]="No ticket found"; 
$LANG['joblist'][9]="New"; 
$LANG['joblist'][10]="Closed (solved)"; 
$LANG['joblist'][11]="Opened on"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="Closed (not solved)"; 
$LANG['joblist'][18]="Processing (assigned)"; 
$LANG['joblist'][19]="Processing (planned)"; 
$LANG['joblist'][21]="Processing"; 
$LANG['joblist'][26]="Pending"; 
$LANG['joblist'][27]="Email for follow-up"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Select a category for this item :"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Edit this item"; 
$LANG['knowbase'][9]="Delete this item"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Category name"; 
$LANG['knowbase'][14]="Subject"; 
$LANG['knowbase'][15]="Contents"; 
$LANG['knowbase'][24]="Access to the Frequently Asked Questions"; 
$LANG['knowbase'][26]="Views"; 
$LANG['knowbase'][27]="On"; 
$LANG['knowbase'][29]="Recent Entries"; 
$LANG['knowbase'][30]="Most popular questions"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Synchronizing already imported users"; 
$LANG['ldap'][2]="Import new users"; 
$LANG['ldap'][3]="No users to be imported"; 
$LANG['ldap'][4]="LDAP directory choice"; 
$LANG['ldap'][5]="Please choose LDAP directory to import users from"; 
$LANG['ldap'][6]="Unable to connect to the LDAP directory"; 
$LANG['ldap'][7]="No LDAP directory defined in GLPI"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Test of connection to LDAP directory"; 
$LANG['ldap'][12]="Synchronization"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="in GLPI"; 
$LANG['ldap'][15]="Synchronize"; 
$LANG['ldap'][16]="Preconfiguration"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Replicate"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Main server"; 
$LANG['ldap'][22]="Replicate(s)"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Import of new groups"; 
$LANG['ldap'][25]="No group to be imported"; 
$LANG['ldap'][30]="How LDAP aliases should be handled"; 
$LANG['ldap'][31]="Never dereferenced (default)"; 
$LANG['ldap'][32]="Always dereferenced"; 
$LANG['ldap'][33]="Dereferenced during the search (but not when locating)"; 
$LANG['ldap'][34]="Dereferenced when locating (not during the search)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Link or Filename"; 
$LANG['links'][4]="Hardware type associated"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="No link defined"; 
$LANG['links'][9]="File content"; 

$LANG['log'][1]="system"; 
$LANG['log'][16]="planning"; 
$LANG['log'][18]="components"; 
$LANG['log'][20]="add an item"; 
$LANG['log'][21]="update item"; 
$LANG['log'][22]="item's deletion"; 
$LANG['log'][23]="restoration of an item"; 
$LANG['log'][24]="purge item"; 
$LANG['log'][26]="disconnect item"; 
$LANG['log'][27]="item connection"; 
$LANG['log'][28]="modification of components"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="associate a type"; 
$LANG['log'][31]="deletion of a type"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="deletion link with an item"; 
$LANG['log'][34]="add a link with a supplier"; 
$LANG['log'][35]="deletion link with supplier"; 
$LANG['log'][40]="IP connection"; 
$LANG['log'][41]="connection failed"; 
$LANG['log'][42]="Reservation"; 
$LANG['log'][44]="Heading"; 
$LANG['log'][45]="Successful"; 
$LANG['log'][46]="Failed"; 
$LANG['log'][48]="add a user to a group"; 
$LANG['log'][49]="user's deletion from group"; 
$LANG['log'][55]="Connection"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="add a user to an entity"; 
$LANG['log'][62]="user's deletion from entity"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="rule"; 
$LANG['log'][66]="Security"; 
$LANG['log'][67]="modification of notes"; 
$LANG['log'][70]="add network port"; 
$LANG['log'][71]="add several network ports"; 
$LANG['log'][73]="deletion of a network port"; 
$LANG['log'][74]="deletion of several network ports"; 
$LANG['log'][75]="network port moved"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="add version"; 
$LANG['log'][83]="modification of version"; 
$LANG['log'][84]="version's deletion"; 
$LANG['log'][85]="add license"; 
$LANG['log'][86]="modification of licence"; 
$LANG['log'][87]="licence's deletion"; 
$LANG['log'][88]="adding cartridges"; 
$LANG['log'][89]="adding consumables"; 
$LANG['log'][90]="deletion of a cartridge"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="cartridge's update"; 
$LANG['log'][95]="cartridge's installation"; 
$LANG['log'][96]="cartridge's uninstallation"; 
$LANG['log'][97]="consumable out for the user"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Last login"; 
$LANG['login'][1]="Log in again"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Access Denied"; 
$LANG['login'][6]="Login"; 
$LANG['login'][7]="Password"; 
$LANG['login'][8]="Empty login or password"; 
$LANG['login'][9]="Not yet authenticated"; 
$LANG['login'][10]="Authentication"; 
$LANG['login'][11]="User not authorized to connect in GLPI"; 
$LANG['login'][12]="Incorrect username or password"; 
$LANG['login'][13]="Password field is empty"; 
$LANG['login'][14]="unknown user"; 
$LANG['login'][15]="User not found or several users found"; 
$LANG['login'][16]="unsuccessful authorization in LDAP"; 
$LANG['login'][18]="GLPI internal database"; 
$LANG['login'][20]="You do not have access to this application because your account was deactivated or removed"; 
$LANG['login'][21]="Test connection to IMAP/POP server"; 
$LANG['login'][22]="Test successful"; 
$LANG['login'][23]="Test failed"; 
$LANG['login'][24]="Last login date"; 
$LANG['login'][25]="You don't have right to connect"; 
$LANG['login'][26]="You must activate the JavaScript function of your navigator"; 
$LANG['login'][27]="You must accept cookies to reach this application"; 
$LANG['login'][30]="Change of the authentication method"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Authentication on GLPI database"; 
$LANG['login'][33]="Authentication on IMAP/POP server"; 

$LANG['mailgate'][0]="Mail Receiver"; 
$LANG['mailgate'][2]="Get email tickets now"; 
$LANG['mailgate'][3]="Number of available and retrieved emails"; 
$LANG['mailgate'][4]="mbstring extension not found. Warning with charsets used."; 
$LANG['mailgate'][5]="Invalid attached file"; 
$LANG['mailgate'][6]="Too large attached file"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Description of the ticket"; 
$LANG['mailing'][10]="New ticket's follow-up"; 
$LANG['mailing'][12]="Ticket assign to"; 
$LANG['mailing'][14]="Update of the category of the ticket"; 
$LANG['mailing'][15]="Update of the priority of the ticket"; 
$LANG['mailing'][17]="Update of the item of the ticket"; 
$LANG['mailing'][18]="Update the author of the ticket"; 
$LANG['mailing'][19]="New reservation"; 
$LANG['mailing'][20]="Update the group of the ticket"; 
$LANG['mailing'][21]="Change in ticket source"; 
$LANG['mailing'][23]="Reservation modification"; 
$LANG['mailing'][26]="Added document :"; 
$LANG['mailing'][27]="Update of the status of the ticket"; 
$LANG['mailing'][29]="Reservation Cancelled"; 
$LANG['mailing'][30]="Ticket Update"; 
$LANG['mailing'][31]="This is a test email to check that the email system works"; 
$LANG['mailing'][32]="Mail Test"; 
$LANG['mailing'][33]="Cartridges Alarm"; 
$LANG['mailing'][35]="Threshold of alarm reached for the type of consumable:"; 
$LANG['mailing'][36]="Consumables Alarm"; 
$LANG['mailing'][37]="Contract entered in notice time:"; 
$LANG['mailing'][39]="Contracts Alarm"; 
$LANG['mailing'][40]="Item arrived at the end of the warranty:"; 
$LANG['mailing'][41]="Financial Information Alarm"; 
$LANG['mailing'][42]="Change in hourly costs"; 
$LANG['mailing'][43]="Change in fixed costs"; 
$LANG['mailing'][44]="Change in material costs"; 
$LANG['mailing'][45]="Change ticket title"; 
$LANG['mailing'][46]="Change ticket description"; 
$LANG['mailing'][47]="Error in sending the email"; 
$LANG['mailing'][48]="Change in opening date"; 
$LANG['mailing'][49]="Change in closing date"; 
$LANG['mailing'][50]="Change ticket receiver"; 
$LANG['mailing'][51]="Expired license :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="No defined category"; 
$LANG['mailing'][101]="Email follow-up has been enabled"; 
$LANG['mailing'][102]="Email follow-up has been disabled"; 
$LANG['mailing'][104]="Follow-up duration"; 
$LANG['mailing'][105]="Not assigned"; 
$LANG['mailing'][107]="Nothing"; 
$LANG['mailing'][109]="No group"; 
$LANG['mailing'][110]="Invalid Email"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Computers"; 
$LANG['Menu'][1]="Networks"; 
$LANG['Menu'][2]="Printers"; 
$LANG['Menu'][3]="Monitors"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Reports"; 
$LANG['Menu'][11]="Settings"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistics"; 
$LANG['Menu'][14]="Users"; 
$LANG['Menu'][15]="Administration"; 
$LANG['Menu'][16]="Devices"; 
$LANG['Menu'][17]="Reservations"; 
$LANG['Menu'][18]="Tools"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Cartridges"; 
$LANG['Menu'][22]="Contacts"; 
$LANG['Menu'][23]="Suppliers"; 
$LANG['Menu'][24]="Financial Information"; 
$LANG['Menu'][25]="Contracts"; 
$LANG['Menu'][26]="Management"; 
$LANG['Menu'][27]="Documents"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planning"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Consumables"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Phones"; 
$LANG['Menu'][35]="Profiles"; 
$LANG['Menu'][36]="Groups"; 
$LANG['Menu'][37]="Entities"; 
$LANG['Menu'][38]="Inventory"; 
$LANG['Menu'][39]="Receivers"; 
$LANG['Menu'][40]="Bookmarks"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Microphone"; 
$LANG['monitors'][15]="Speakers"; 
$LANG['monitors'][18]="Flags"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Size"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Network port"; 
$LANG['networking'][13]="networking ports found"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Connected to"; 
$LANG['networking'][19]="Add networking port..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="on"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="The port"; 
$LANG['networking'][46]="Add several ports..."; 
$LANG['networking'][47]="From"; 
$LANG['networking'][48]="To"; 
$LANG['networking'][51]="Network outlet"; 
$LANG['networking'][55]="Associate a VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Choose a MAC address in the list or specify it below"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Mask"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Import Options"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][10]="Global import"; 
$LANG['ocsconfig'][11]="No import"; 
$LANG['ocsconfig'][12]="Unit import"; 
$LANG['ocsconfig'][13]="Unit import: everything is imported 'as-is'"; 
$LANG['ocsconfig'][14]="Global import: everything is imported but the material is globally managed (without double blooms)"; 
$LANG['ocsconfig'][15]="No import: the plugin will not import these elements"; 
$LANG['ocsconfig'][16]="Default status"; 
$LANG['ocsconfig'][17]="Limit the import to the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][18]="Check first that duplicates have been correctly managed in OCSNG"; 
$LANG['ocsconfig'][19]="Unit import on serial number"; 
$LANG['ocsconfig'][27]="General informations"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Ports"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registry"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Behavior when disconnecting"; 
$LANG['ocsconfig'][49]="Trash"; 
$LANG['ocsconfig'][50]="Deletion"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="empty"; 
$LANG['ocsconfig'][57]="equal"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Synchronize computers already imported"; 
$LANG['ocsng'][2]="Import new computers"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Link new OCS computers to existing GLPI computers"; 
$LANG['ocsng'][5]="Import new computers"; 
$LANG['ocsng'][6]="Auto update"; 
$LANG['ocsng'][7]="Imported from OCSNG"; 
$LANG['ocsng'][8]="Import successful"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Update computers"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Import date in GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="No field locked"; 
$LANG['ocsng'][16]="Locked Fields"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Caution! The imported data (see your configuration) will overwrite the existing data"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Force Synchronization"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Locked monitor(s)"; 
$LANG['ocsng'][32]="Locked device(s)"; 
$LANG['ocsng'][34]="Locked printer(s)"; 
$LANG['ocsng'][36]="Destination entity"; 
$LANG['ocsng'][37]="Enable preview"; 
$LANG['ocsng'][38]="Disable the preview"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Manual import mode"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Locked IP(s)"; 
$LANG['ocsng'][52]="Locked software(s)"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volume(s) locked(s)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="to"; 
$LANG['pager'][2]="from"; 
$LANG['pager'][3]="of"; 
$LANG['pager'][4]="Display"; 
$LANG['pager'][5]="items"; 

$LANG['peripherals'][18]="Brand"; 
$LANG['peripherals'][31]="Global management"; 
$LANG['peripherals'][32]="Unit management"; 
$LANG['peripherals'][33]="Management Type"; 

$LANG['phones'][18]="Brand"; 
$LANG['phones'][36]="Power Supply"; 
$LANG['phones'][38]="Headset"; 
$LANG['phones'][39]="Speaker"; 
$LANG['phones'][40]="Number of lines"; 

$LANG['planning'][0]="The technician requested already has an appointment planned for this time."; 
$LANG['planning'][1]="Error in entering dates. The starting date is later than the ending date"; 
$LANG['planning'][5]="Day"; 
$LANG['planning'][6]="Week"; 
$LANG['planning'][8]="Tracking"; 
$LANG['planning'][9]="By"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// Synchronization"; 
$LANG['planning'][14]="Month"; 
$LANG['planning'][15]="Your planning"; 
$LANG['planning'][16]="Information"; 
$LANG['planning'][17]="To do"; 
$LANG['planning'][18]="Done"; 

$LANG['plugins'][0]="Plugins list"; 
$LANG['plugins'][2]="Installed / not configured"; 
$LANG['plugins'][3]="Installed / not activated"; 
$LANG['plugins'][4]="Error / to clean"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serial"; 
$LANG['printers'][15]="Parallel"; 
$LANG['printers'][18]="Ports"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Initial page counter"; 
$LANG['printers'][31]="Printed pages"; 

$LANG['profiles'][0]="Global right"; 
$LANG['profiles'][1]="Entity Right"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Create a ticket"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Show all tickets"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Read"; 
$LANG['profiles'][11]="Write"; 
$LANG['profiles'][12]="No Access"; 
$LANG['profiles'][13]="Default Profile"; 
$LANG['profiles'][14]="Ticket's deletion"; 
$LANG['profiles'][15]="Add a followup to all tickets"; 
$LANG['profiles'][16]="To be in charge of a ticket"; 
$LANG['profiles'][17]="Steal a ticket"; 
$LANG['profiles'][18]="Update a ticket"; 
$LANG['profiles'][19]="Assign a ticket"; 
$LANG['profiles'][20]="View personnal planning"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profile"; 
$LANG['profiles'][23]="Administration of reservations"; 
$LANG['profiles'][24]="Update Password"; 
$LANG['profiles'][26]="Show tickets created by my groups"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Recursive"; 
$LANG['profiles'][29]="Dynamic"; 
$LANG['profiles'][30]="View OCSNG information"; 
$LANG['profiles'][31]="Synchronize OCSNG manually"; 
$LANG['profiles'][32]="See assigned tickets (personnal + group associated)"; 
$LANG['profiles'][33]="No user founded"; 
$LANG['profiles'][34]="Caption"; 
$LANG['profiles'][35]="Update all followups"; 
$LANG['profiles'][36]="See schedule of people in my groups"; 
$LANG['profiles'][37]="Default entity"; 
$LANG['profiles'][38]="Visibility"; 
$LANG['profiles'][39]="Assignment"; 
$LANG['profiles'][40]="Update"; 
$LANG['profiles'][41]="Creation"; 
$LANG['profiles'][42]="Association"; 
$LANG['profiles'][43]="Method for user authentication and synchronization"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Path"; 
$LANG['registry'][3]="Key/value"; 
$LANG['registry'][4]="Registry key(s) found"; 
$LANG['registry'][5]="No key found in registry"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Personal notes"; 
$LANG['reminder'][1]="Public notes"; 
$LANG['reminder'][6]="New note"; 
$LANG['reminder'][9]="Text"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Without Title"; 
$LANG['reminder'][16]="Global notes"; 

$LANG['reports'][0]="Select the report you want to generate"; 
$LANG['reports'][4]="List of the hardware under contract"; 
$LANG['reports'][11]="Hardware under contract"; 
$LANG['reports'][12]="Hardware Type"; 
$LANG['reports'][13]="Date(s)"; 
$LANG['reports'][15]="Display report"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Default report"; 
$LANG['reports'][27]="By contract"; 
$LANG['reports'][28]="By year"; 
$LANG['reports'][33]="Network report"; 
$LANG['reports'][36]="Connected devices"; 
$LANG['reports'][37]="Network outlets"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="By location"; 
$LANG['reports'][41]="By hardware"; 
$LANG['reports'][42]="By network outlet"; 
$LANG['reports'][46]="hardware ports"; 
$LANG['reports'][47]="device ports"; 
$LANG['reports'][49]="Network report by hardware"; 
$LANG['reports'][51]="Network report by outlet"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Network report by location"; 
$LANG['reports'][57]="Material list"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Opening date"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="Other Financial Information (licences, cartridges, consumables)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Reservable Items"; 
$LANG['reservation'][2]="Device temporarily unavailable"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Reserve"; 
$LANG['reservation'][9]="Reserve an item"; 
$LANG['reservation'][16]="To"; 
$LANG['reservation'][17]="From"; 
$LANG['reservation'][18]="The required item is already reserved for this timeframe"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modify the comment"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="By week"; 
$LANG['reservation'][29]="By day"; 
$LANG['reservation'][30]="times"; 
$LANG['reservation'][31]="By"; 
$LANG['reservation'][35]="Current and future reservations"; 
$LANG['reservation'][36]="Past Reservations"; 
$LANG['reservation'][37]="No Reservations"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="That will remove all the reservations in progress."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="is"; 
$LANG['rulesengine'][1]="is not"; 
$LANG['rulesengine'][2]="contains"; 
$LANG['rulesengine'][3]="does not contain"; 
$LANG['rulesengine'][4]="starting with"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Criteria"; 
$LANG['rulesengine'][7]="Actions"; 
$LANG['rulesengine'][8]="Rules management"; 
$LANG['rulesengine'][9]="Logical operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Action type"; 
$LANG['rulesengine'][12]="Fields"; 
$LANG['rulesengine'][13]="Value"; 
$LANG['rulesengine'][14]="Condition"; 
$LANG['rulesengine'][15]="Reason"; 
$LANG['rulesengine'][16]="Criteria"; 
$LANG['rulesengine'][17]="Rules"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Entity and rights assignment rules"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Assign"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Rule type"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="List rules"; 
$LANG['rulesengine'][30]="Action"; 
$LANG['rulesengine'][33]="Dropdown dictionary"; 
$LANG['rulesengine'][35]="Software dictionary"; 
$LANG['rulesengine'][36]="Manufacturer dictionary"; 
$LANG['rulesengine'][37]="Rules for assigning a category to software"; 
$LANG['rulesengine'][38]="Recalculate"; 
$LANG['rulesengine'][40]="the category"; 
$LANG['rulesengine'][41]="Validation"; 
$LANG['rulesengine'][42]="AND"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Assign: equipment by IP address"; 
$LANG['rulesengine'][47]="Assign: equipment by name + domain"; 
$LANG['rulesengine'][48]="Assign equipment"; 
$LANG['rulesengine'][49]="Assign: equipment by MAC address"; 
$LANG['rulesengine'][50]="Computer model dictionary"; 
$LANG['rulesengine'][51]="Monitor model dictionary"; 
$LANG['rulesengine'][52]="Phone model dictionary"; 
$LANG['rulesengine'][53]="Peripheral model dictionary"; 
$LANG['rulesengine'][54]="Printer model dictionary"; 
$LANG['rulesengine'][55]="Networking model dictionary"; 
$LANG['rulesengine'][56]="Models"; 
$LANG['rulesengine'][60]="Computer type dictionary"; 
$LANG['rulesengine'][61]="Monitor type dictionary"; 
$LANG['rulesengine'][62]="Phone type dictionary"; 
$LANG['rulesengine'][63]="Peripheral type dictionary"; 
$LANG['rulesengine'][64]="Printer type dictionary"; 
$LANG['rulesengine'][65]="Networking device type dictionary"; 
$LANG['rulesengine'][66]="Types"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Service Pack dictionary"; 
$LANG['rulesengine'][69]="OS versions dictionary"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Rename based on dictionary"; 
$LANG['rulesengine'][77]="Dictionaries"; 
$LANG['rulesengine'][78]="Version"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Global dictionary"; 
$LANG['rulesengine'][81]="Rule results"; 
$LANG['rulesengine'][82]="Result details"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Test rules engine"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software deleted by GLPI dictionary"; 
$LANG['rulesengine'][90]="Work in progress..."; 
$LANG['rulesengine'][91]="Work ended."; 
$LANG['rulesengine'][92]="Warning before running rename based on the dictionary"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Manufacturer choice"; 
$LANG['rulesengine'][96]="Rename based on the manufacturer(s)dictionary<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="No element to be tested"; 
$LANG['rulesengine'][100]="Cache informations"; 
$LANG['rulesengine'][102]="Rule name"; 
$LANG['rulesengine'][103]="Objects in cache"; 
$LANG['rulesengine'][104]="Original value"; 
$LANG['rulesengine'][105]="Modified value"; 
$LANG['rulesengine'][106]="Unchanged"; 
$LANG['rulesengine'][107]="Inactive"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Rights assignment"; 
$LANG['rulesengine'][111]="Entities assignment"; 
$LANG['rulesengine'][112]="Rights and entities assignment"; 
$LANG['rulesengine'][120]="The engine stops on the first checked rule."; 
$LANG['rulesengine'][121]="The engine treats all the rules."; 
$LANG['rulesengine'][122]="The engine passes the result of a rule to the following ones."; 
$LANG['rulesengine'][130]="Entity from LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Search"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="contains"; 
$LANG['search'][4]="sorted by"; 
$LANG['search'][8]="Start date"; 
$LANG['search'][9]="End date"; 
$LANG['search'][10]="in"; 
$LANG['search'][11]="Items Seen"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="No item found"; 
$LANG['search'][16]="A least"; 
$LANG['search'][17]="Add a search criterium"; 
$LANG['search'][18]="Delete a search criteria"; 
$LANG['search'][19]="Add a global search criterium"; 
$LANG['search'][20]="Delete a global search criteria"; 

$LANG['setup'][0]="Dropdowns"; 
$LANG['setup'][2]="Add user..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Computers Types"; 
$LANG['setup'][5]="Operating Systems"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Network Interfaces"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Select Language"; 
$LANG['setup'][42]="Networking Types"; 
$LANG['setup'][43]="Printer Types"; 
$LANG['setup'][44]="Monitor Types"; 
$LANG['setup'][45]="Case Type"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Select the category to configure"; 
$LANG['setup'][63]="Caution: you're about to remove a heading used for one or more items"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="You can also replace all the events of this heading by another:"; 
$LANG['setup'][67]="External authentications"; 
$LANG['setup'][69]="Devices types"; 
$LANG['setup'][70]="General setup"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Network outlet"; 
$LANG['setup'][74]="You can't delete that place, because it has sub-places"; 
$LANG['setup'][75]="As child of"; 
$LANG['setup'][79]="Categories of the tickets"; 
$LANG['setup'][80]="Third party Type"; 
$LANG['setup'][81]="Document Headings"; 
$LANG['setup'][82]="Contact Type"; 
$LANG['setup'][83]="Item Status"; 
$LANG['setup'][84]="Cartridge Type"; 
$LANG['setup'][85]="Contract Type"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Network"; 
$LANG['setup'][89]="Domain"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Computers Models"; 
$LANG['setup'][92]="Consumables Type"; 
$LANG['setup'][93]="Interfaces (Hard Drive...)"; 
$LANG['setup'][94]="Monitors Models"; 
$LANG['setup'][95]="Networking Models"; 
$LANG['setup'][96]="Printers Models"; 
$LANG['setup'][97]="Peripherals Models"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Log Level"; 
$LANG['setup'][103]="1- Critical (login error only)"; 
$LANG['setup'][104]="2- Severe (Not used)"; 
$LANG['setup'][105]="3- Important (successful logins)"; 
$LANG['setup'][106]="4- Notices (Add, delete, tracking)"; 
$LANG['setup'][107]="5- Complete (All)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Default language"; 
$LANG['setup'][114]="Priority colours"; 
$LANG['setup'][115]="Default threshold for cartridge and consumable count"; 
$LANG['setup'][116]="Automatically assign the tickets to the technical person in charge"; 
$LANG['setup'][117]="Authorize anonymous view of the FAQs"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Automatically add users from an external authentication source"; 
$LANG['setup'][125]="... From an external source"; 
$LANG['setup'][126]="Automatically add a user of an external source"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Date Format"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Enable OCSNG mode"; 
$LANG['setup'][134]="OCSNG Mode"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Translation"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="Use GLPI in Mode"; 
$LANG['setup'][139]="Common"; 
$LANG['setup'][140]="Types"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Step for the hours"; 
$LANG['setup'][149]="Number of decimals in amounts"; 
$LANG['setup'][150]="Number Format"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (for non anonymous binds)"; 
$LANG['setup'][156]="Pass (for non-anonymous binds)"; 
$LANG['setup'][157]="The LDAP extension of your PHP parser isn't installed"; 
$LANG['setup'][158]="Impossible to use LDAP as external source of connection"; 
$LANG['setup'][159]="Connection filter"; 
$LANG['setup'][162]="IMAP/POP configuration"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="Your PHP parser was compiled without the IMAP functions"; 
$LANG['setup'][166]="Impossible to use IMAP/POP as external source of connection"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Connection options"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Port (optional)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Root directory (optional)"; 
$LANG['setup'][177]="CAS configuration"; 
$LANG['setup'][178]="The CURL or DOMXML extension for your PHP parser isn't installed"; 
$LANG['setup'][179]="Impossible to use CAS as external source of connection"; 
$LANG['setup'][180]="Use TLS"; 
$LANG['setup'][181]="ldap_start_tls does not exist"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Time zone"; 
$LANG['setup'][190]="x509 certificate"; 
$LANG['setup'][191]="email attribute for x509"; 
$LANG['setup'][192]="Enabled"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Keep status"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Copy computer status"; 
$LANG['setup'][198]="Set status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator Email"; 
$LANG['setup'][204]="Email Signature"; 
$LANG['setup'][205]="Email sent to administrator"; 
$LANG['setup'][206]="Failed to send email to administrator"; 
$LANG['setup'][207]="Administrator reply-to Email (if needed)"; 
$LANG['setup'][217]="The PHP mail function is unknown or isn't activated on your system"; 
$LANG['setup'][218]="The use of a SMTP is needed"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Limit of the schedules for planning"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="Former technician in charge of the ticket"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Technician in charge of this ticket"; 
$LANG['setup'][240]="Notification options"; 
$LANG['setup'][241]="No personal criteria. Create personal parameters?"; 
$LANG['setup'][242]="Alarms options"; 
$LANG['setup'][243]="Alarms on consumables"; 
$LANG['setup'][244]="Alarms on cartridges"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Alarms on contracts"; 
$LANG['setup'][247]="Alarms on financial information"; 
$LANG['setup'][248]="Group in charge of the ticket"; 
$LANG['setup'][249]="Requester group"; 
$LANG['setup'][250]="Display search results by default"; 
$LANG['setup'][252]="Select default items to show"; 
$LANG['setup'][253]="Filter to search in groups"; 
$LANG['setup'][254]="Search type"; 
$LANG['setup'][255]="Group attribute containing its users"; 
$LANG['setup'][256]="In users"; 
$LANG['setup'][257]="In groups"; 
$LANG['setup'][258]="Users & Groups"; 
$LANG['setup'][259]="Belonging to groups"; 
$LANG['setup'][260]="User attribute containing its groups"; 
$LANG['setup'][261]="Group DN"; 
$LANG['setup'][262]="Use DN in the search"; 
$LANG['setup'][263]="Search filter for users"; 
$LANG['setup'][264]="Alarms on expired licenses"; 
$LANG['setup'][271]="Restrict monitor management"; 
$LANG['setup'][272]="Restrict device management"; 
$LANG['setup'][273]="Restrict phone management"; 
$LANG['setup'][274]="for manual add"; 
$LANG['setup'][275]="Restrict printer management"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Copy"; 
$LANG['setup'][284]="Clear"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Check if a new version is available"; 
$LANG['setup'][301]="A new version is available:"; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="You have the latest available version"; 
$LANG['setup'][304]="Connection failed. If you use a proxy, please configure it."; 
$LANG['setup'][305]="Every day"; 
$LANG['setup'][306]="Check for upgrade"; 
$LANG['setup'][307]="Never"; 
$LANG['setup'][308]="Each week"; 
$LANG['setup'][309]="Each month"; 
$LANG['setup'][310]="Impossible to connect to site."; 
$LANG['setup'][311]="Failed to connect to the proxy server"; 
$LANG['setup'][312]="No data available on the web site"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Link with items for the creation of tickets"; 
$LANG['setup'][351]="All Items"; 
$LANG['setup'][352]="Linkable items to a ticket"; 
$LANG['setup'][360]="Automatic fields (marked by *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Default heading when adding a document to a ticket"; 
$LANG['setup'][503]="Phones models"; 
$LANG['setup'][504]="Phones Types"; 
$LANG['setup'][505]="Power supply type of phones"; 
$LANG['setup'][601]="LDAP Value"; 
$LANG['setup'][602]="Connection to OCSNG database"; 
$LANG['setup'][603]="Add a user"; 
$LANG['setup'][604]="Associate to a group"; 
$LANG['setup'][606]="Unable to add. The user already exists."; 
$LANG['setup'][607]="Associate to a profile"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Compulsory title of the ticket"; 
$LANG['setup'][611]="Compulsory ticket content"; 
$LANG['setup'][612]="Compulsory ticket category"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="General"; 
$LANG['setup'][704]="Notifications"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replicate"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Database"; 
$LANG['setup'][803]="Difference between master and slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave database out of sync!"; 
$LANG['setup'][809]="MySQL replica: read only"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Purchase version"; 
$LANG['software'][2]="Version in use"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Unlimited"; 
$LANG['software'][5]="Versions"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Add a version"; 
$LANG['software'][8]="Add a license"; 
$LANG['software'][11]="Licenses"; 
$LANG['software'][17]="Installed Software"; 
$LANG['software'][19]="Installations"; 
$LANG['software'][20]="Remaining"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Update"; 
$LANG['software'][30]="Type of license"; 
$LANG['software'][32]="Expiration"; 
$LANG['software'][44]="Install software"; 
$LANG['software'][45]="Uninstall software"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Merging"; 
$LANG['software'][48]="Merge"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Assigned to the computer"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Software categories"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Item Type"; 
$LANG['state'][7]="No items found"; 
$LANG['state'][11]="Summary"; 

$LANG['stats'][0]="Select statistics to be displayed"; 
$LANG['stats'][1]="Global"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="By item"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Average resolution delay"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Number of resolved tickets"; 
$LANG['stats'][13]="Number of tickets"; 
$LANG['stats'][15]="Average resolution delay"; 
$LANG['stats'][16]="Technician name"; 
$LANG['stats'][20]="Username"; 
$LANG['stats'][23]="No statistics are available"; 
$LANG['stats'][25]="Average (real) duration of ticket"; 
$LANG['stats'][27]="Total (real) duration of ticket"; 
$LANG['stats'][30]="Average delay to respond to the ticket"; 
$LANG['stats'][31]="Day(s)"; 
$LANG['stats'][33]="Min(s)"; 
$LANG['stats'][34]="Sec(s)"; 
$LANG['stats'][35]="Ticket(s)"; 
$LANG['stats'][44]="Supplier Name"; 
$LANG['stats'][45]="By hardware"; 
$LANG['stats'][47]="By ticket"; 
$LANG['stats'][48]="(assigned)"; 
$LANG['stats'][49]="(follow-ups)"; 

$LANG['title'][5]="Knowledge base"; 
$LANG['title'][6]="Networking equipment"; 
$LANG['title'][9]="Item Status"; 
$LANG['title'][10]="Ticket Follow-up"; 
$LANG['title'][13]="User Information"; 
$LANG['title'][14]="External authentication sources"; 
$LANG['title'][24]="Assistance"; 
$LANG['title'][26]="Main"; 
$LANG['title'][27]="Connections"; 
$LANG['title'][28]="Tickets"; 
$LANG['title'][30]="Components"; 
$LANG['title'][33]="External Links"; 
$LANG['title'][34]="Links"; 
$LANG['title'][37]="Notes"; 
$LANG['title'][38]="Historical"; 
$LANG['title'][40]="Public and Personal notes"; 
$LANG['title'][42]="Bulk modification"; 
$LANG['title'][43]="Registry"; 

$LANG['tracking'][1]="My devices"; 
$LANG['tracking'][2]="Or complete search"; 
$LANG['tracking'][3]="Invalid dates. Update cancelled."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="No description for your ticket, please retry."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Document Ticket"; 
$LANG['tracking'][29]="Number"; 
$LANG['tracking'][30]="New"; 
$LANG['tracking'][31]="Processing (assigned)"; 
$LANG['tracking'][32]="Processing (planned)"; 
$LANG['tracking'][34]="Direct"; 
$LANG['tracking'][35]="Written"; 
$LANG['tracking'][37]="Keep tickets when purging hardware in the inventory"; 
$LANG['tracking'][38]="An email was sent to"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Transfer"; 
$LANG['transfer'][3]="If no longer in use"; 
$LANG['transfer'][4]="To empty the list of elements to be transferred"; 
$LANG['transfer'][5]="You can continue to add elements to be transferred or execute the transfer now"; 
$LANG['transfer'][6]="Think of making a backup before transferring items."; 
$LANG['transfer'][7]="Items to transfer"; 
$LANG['transfer'][8]="Transfer mode"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Error during the database update"; 
$LANG['update'][91]="Caution!"; 
$LANG['update'][92]="You will update the GLPI database named :"; 
$LANG['update'][93]="Database connection successful"; 
$LANG['update'][94]="Update successful, your database is up to date"; 
$LANG['update'][95]="Connection to database failed, verify the connection parameters included in config_db.php file"; 
$LANG['update'][96]="All users having administrators rights have have been updated to 'super-admin' rights with the creation of his new user type."; 
$LANG['update'][105]="Impossible to accomplish an update this way!!"; 
$LANG['update'][106]="Go back to GLPI"; 
$LANG['update'][107]="You must now proceed to updating your database content"; 
$LANG['update'][130]="Locations Update"; 
$LANG['update'][131]="The new structure is hierarchical"; 
$LANG['update'][132]="Provide a delimiter in order to automate the new hierarchy generation."; 
$LANG['update'][133]="You can also specify a root location which will include all the generated locations."; 
$LANG['update'][134]="Delimiter"; 
$LANG['update'][135]="Root location"; 
$LANG['update'][136]="This is the new hierarchy. If it's complete approve it."; 
$LANG['update'][137]="New hierarchy"; 
$LANG['update'][138]="Actual locations"; 
$LANG['update'][139]="Optimizing tables"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Title"; 
$LANG['users'][2]="Category (class)"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>